system.SiteConfig (Site configuration) — amici1

# `system.SiteConfig` (Site configuration)

SiteConfig(id, default_build_method, simulate_today, site_company)

Master tables : system.SiteConfigs (Site configurations)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Default build method (default_build_method) : The default build method to use when rendering printable documents.

- Simulated date (simulate_today) : A constant user-defined date to be substituted as current system date.

- Site operator (site_company) : The site operator, i.e. the legal person that operates this Lino site.

- Next partner id (next_partner_id) : The next automatic id for any new partner.

- Default Event Type (default_event_type) : The default type of events on this site.

- Site Calendar (site_calendar) : The default calendar of this site.

- Max automatic events (max_auto_events) : Maximum number of automatic events to be generated.

- Hide events before (hide_events_before) : If this is not empty, any calendar events before that date are being hidden in certain places.

- Default guest role for participants (pupil_guestrole) : See `<django.db.models.fields.related.ForeignKey: pupil_guestrole>`.

- Name (name_column) : See `lino.modlib.system.models.SiteConfig.name_column`.

- (None) (navigation_panel) : See `lino.modlib.system.models.SiteConfig.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.system.models.SiteConfig.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
default_build_method | Default build method | The default build method to use when rendering printable documents.
simulate_today | Simulated date | A constant user-defined date to be substituted as current system date.
site_company | Site operator | The site operator, i.e. the legal person that operates this Lino site.
next_partner_id | Next partner id | The next automatic id for any new partner.
default_event_type | Default Event Type | The default type of events on this site.
site_calendar | Site Calendar | The default calendar of this site.
max_auto_events | Max automatic events | Maximum number of automatic events to be generated.
hide_events_before | Hide events before | If this is not empty, any calendar events before that date are being hidden in certain places.
pupil_guestrole | Default guest role for participants |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |